@@ -1,5 +1,5 @@
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'ABIFLAGS': 'm',
+build_time_vars = {'ABIFLAGS': '@ABIFLAGS@',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ANDROID_API_LEVEL': 0,
@@ -9,8 +9,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/opt/anaconda1anaconda2anaconda3/bin',
- 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
- 'BLDLIBRARY': '-L. -lpython3.6m',
+ 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@',
+ 'BLDLIBRARY': '-L. -lpython@PYVER@@ABIFLAGS@',
  'BLDSHARED': 'gcc -bundle -undefined dynamic_lookup '
               '-L/opt/anaconda1anaconda2anaconda3/lib  '
               '-arch x86_64 '
@@ -49,21 +49,21 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "-arch x86_64' "
                 "'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
+ 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python@PYVER@@ABIFLAGS@',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3/coverage.info',
- 'COVERAGE_REPORT': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3/lcov-report',
+ 'COVERAGE_INFO': '/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@/coverage.info',
+ 'COVERAGE_REPORT': '/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++',
  'DESTDIRS': '/opt/anaconda1anaconda2anaconda3 '
              '/opt/anaconda1anaconda2anaconda3/lib '
-             '/opt/anaconda1anaconda2anaconda3/lib/python3.6 '
-             '/opt/anaconda1anaconda2anaconda3/lib/python3.6/lib-dynload',
- 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
+             '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@ '
+             '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@/lib-dynload',
+ 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -88,7 +88,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-36m-darwin.so',
+ 'EXT_SUFFIX': '.cpython-@PYVERNODOTS@@ABIFLAGS@-darwin.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -479,16 +479,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HOST_GNU_TYPE': 'x86_64-apple-darwin13.4.0',
  'INCLDIRSTOMAKE': '/opt/anaconda1anaconda2anaconda3/include '
                    '/opt/anaconda1anaconda2anaconda3/include '
-                   '/opt/anaconda1anaconda2anaconda3/include/python3.6m '
-                   '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
+                   '/opt/anaconda1anaconda2anaconda3/include/python@PYVER@@ABIFLAGS@ '
+                   '/opt/anaconda1anaconda2anaconda3/include/python@PYVER@@ABIFLAGS@',
  'INCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
+ 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python@PYVER@@ABIFLAGS@',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.6m.dylib',
+ 'INSTSONAME': 'libpython@PYVER@@ABIFLAGS@.dylib',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -bundle -undefined dynamic_lookup',
@@ -497,24 +497,24 @@ build_time_vars = {'ABIFLAGS': 'm',
             '-L/opt/anaconda1anaconda2anaconda3/lib  '
             '-arch x86_64',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6m.dylib',
+ 'LDLIBRARY': 'libpython@PYVER@@ABIFLAGS@.dylib',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -bundle -undefined dynamic_lookup '
              '-L/opt/anaconda1anaconda2anaconda3/lib  '
              '-arch x86_64 '
              '-L/opt/anaconda1anaconda2anaconda3/lib  '
              '-arch x86_64',
- 'LDVERSION': '3.6m',
+ 'LDVERSION': '@PYVER@@ABIFLAGS@',
  'LIBC': '',
- 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
+ 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@',
  'LIBDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/opt/anaconda1anaconda2anaconda3/lib/pkgconfig',
- 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python3.6/config-3.6m-darwin',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@/config-@PYVER@@ABIFLAGS@-darwin',
+ 'LIBRARY': 'libpython@PYVER@@ABIFLAGS@.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl  -framework CoreFoundation',
@@ -532,8 +532,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACHDEP': 'darwin',
  'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
- 'MACOSX_DEPLOYMENT_TARGET': '10.7',
+ 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python@PYVER@',
+ 'MACOSX_DEPLOYMENT_TARGET': '10.9',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
@@ -626,7 +626,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3',
+ 'RUNSHARED': 'DYLD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@',
  'SCRIPTDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -652,7 +652,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m-darwin',
+ 'SOABI': 'cpython-@PYVERNODOTS@@ABIFLAGS@-darwin',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
@@ -667,10 +667,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3 '
+ 'TESTPYTHON': 'DYLD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@ '
                './python.exe',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3 '
+ 'TESTRUNNER': 'DYLD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@ '
                './python.exe ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -681,7 +681,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
- 'VERSION': '3.6',
+ 'VERSION': '@PYVER@',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
@@ -694,8 +694,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3',
- 'abs_srcdir': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.6.3',
+ 'abs_builddir': '/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@',
+ 'abs_srcdir': '/opt/anaconda1anaconda2anaconda3/../work/Python-@PYVERFULL@',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
  'prefix': '/opt/anaconda1anaconda2anaconda3',
